@@ -36,7 +36,7 @@ class MILOU_EXPORT PreviewPlugin : public QObject
     Q_OBJECT
 public:
     explicit PreviewPlugin(QObject* parent);
-    virtual ~PreviewPlugin();
+    ~PreviewPlugin() override;
 
     /**
      * Return a list of mimetype which this plugin supports. These mimetypes
@@ -86,7 +86,7 @@ signals:
 
 protected:
     /**
-     * Highlights all the occurance of highlight in the document
+     * Highlights all the occurrences of highlight in the document
      */
     void highlight(const QTextDocument* doc) const;
 
